SurfaceData

Struct SurfaceData 

pub struct SurfaceData<U> { /* private fields */ }
Data associated with a [WlSurface].

Implementations

Source

impl<U> SurfaceData<U>

pub fn new( parent_surface: Option<WlSurface>, scale_factor: i32, udata: U, ) -> Self

Create a new surface that initially reports the given scale factor and parent.

pub fn data(&self) -> &U

pub fn data_mut(&mut self) -> &mut U

pub fn scale_factor(&self) -> i32

The scale factor of the output with the highest scale factor.

pub fn transform(&self) -> Transform

The suggest transform for the surface.

pub fn parent_surface(&self) -> Option<&WlSurface>

The parent surface used for this surface.

The surface is Some for primarily for subsurfaces, since they must have a parent surface.

pub fn outputs(&self) -> impl Iterator<Item = WlOutput>

The outputs the surface is currently inside.