pub struct SurfaceData<U> { /* private fields */ }Expand description
Data associated with a [WlSurface].
Implementations
Sourceimpl<U> SurfaceData<U>
impl<U> SurfaceData<U>
Sourcepub fn new(
parent_surface: Option<WlSurface>,
scale_factor: i32,
udata: U,
) -> Self
pub fn new( parent_surface: Option<WlSurface>, scale_factor: i32, udata: U, ) -> Self
Create a new surface that initially reports the given scale factor and parent.
pub fn data(&self) -> &U
pub fn data_mut(&mut self) -> &mut U
Sourcepub fn scale_factor(&self) -> i32
pub fn scale_factor(&self) -> i32
The scale factor of the output with the highest scale factor.
Sourcepub fn parent_surface(&self) -> Option<&WlSurface>
pub fn parent_surface(&self) -> Option<&WlSurface>
The parent surface used for this surface.
The surface is Some for primarily for subsurfaces,
since they must have a parent surface.